@@ -1,25 +1,9 @@
-import numpy as np
-import wave
 import ctypes
 import builtins
 import os
 import sys
 
-def read_wav(path): 
-  """returns signal & fps"""
-  wav = wave.open(path , 'r')
-  signal = np.frombuffer(wav.readframes(-1) , np.int16).astype(np.double)
-  fps = wav.getframerate()
-  return signal, fps
-
-def save_wav(signal, name = 'test.wav', fps = 44100): 
-  '''save .wav file to program folder'''
-  o = wave.open(name, 'wb')
-  o.setframerate(fps)
-  o.setnchannels(1)
-  o.setsampwidth(2)
-  o.writeframes(np.int16(signal)) # Int16
-  o.close()
+from .envelope import read_wav, save_wav
 
 test_int = 5
 cppmode = True
@@ -28,7 +12,7 @@ try:
   dir = os.path.dirname(sys.modules["signal_envelope"].__file__)
   path = os.path.join(dir, "envelope.dll")
 except:
-  print("Could not resolve the path to 'envelope.dll'")
+  print("Could not resolve path to 'envelope.dll'")
 
 try:
   lib = ctypes.CDLL(path)
@@ -47,7 +31,7 @@ if cppmode:
   builtins.lib = lib
   from .envelope import get_frontiers_cpp as get_frontiers
 else:
-  print("Running in Python mode (significantly slower)")
+  print("Running in Python mode (Slower)")
   from .envelope import get_frontiers_py as get_frontiers
 
 
